function [e11,e12,e13,e14,e15,e19]=average_plot(A,B,maxit,verb)
% function [e11,e12,e13,e14,e15,e19] =average_plot(A,B,maxit,verb)
% Input:
% A and B are cell arrays such that A{i} and B{i} are nxn positive
% definite matrices.
% maxit: maximum number of iterations. Suggested values:
%   25, 10, 16, 6 for tests 1,2,3,4, respectively
% verb: if true, some information is printed on the screen on run time
% Output:
% the vectors with the errors per steps of the algorithms in equation
% (11)--(15), (19) of the paper
% Bini, Iannazzo, Computational aspects of the geometric mean of 
% two matrices: a survey
% This function is used in the script script_figure_1 to draw the plots 
% in Figure 1 of the above paper for cell arrays A,B generated by the 
% function data_set(test,ntests,n) with test=1,2,3,4, n=200, and 
% ntests=100

ntsts = length(A);
nograph = false;
e11=0;e12=0;e13=0;e14=0;e15=0;e19=0;
a=A{1};b=B{1};
[~,e11] = avit(a,b,verb,maxit,nograph);
[~,e12] = avit1(a,b,verb,maxit,nograph);
[~,e13] = avit_unstable(a,b,verb,maxit);
luns=length(e13);
[~,e14] = avit_3_term_scaled(a,b,verb,maxit,nograph);
[~,e15] = avit_sign_scaled(a,b,verb,maxit,nograph);
[~,e19] = polar_based_mean_it(a,b,verb,maxit,nograph);
for nt=2:ntsts
    nt
   a = A{nt}; b=B{nt};
   [~,s11] = avit(a,b,false,maxit,nograph);
   [~,s12] = avit1(a,b,verb,maxit,nograph);
   [~,s13] = avit_unstable(a,b,verb,maxit);
   luns=min(luns,length(s13));
   [~,s14] = avit_3_term_scaled(a,b,verb,maxit,nograph);
   [~,s15] = avit_sign_scaled(a,b,verb,maxit,nograph);
   [~,s19] = polar_based_mean_it(a,b,verb,maxit,nograph);
   e11 = e11+s11;
   e12 = e12+s12;
   e13(1:luns)=e13(1:luns)+s13(1:luns);
   e14 = e14+s14;
   e15 = e15+s15;
   e19 = e19+s19;
end
e11=e11/ntsts;
e12=e12/ntsts;
e13=e13/ntsts;
e14=e14/ntsts;
e15=e15/ntsts;
e19=e19/ntsts;

figure
  semilogy(e11,'o-','linewidth',2,'markersize',10);
  hold on
  semilogy(e12,'s-','linewidth',2,'markersize',10);
  semilogy(e13(1:luns),'d-','linewidth',2,'markersize',10);
  semilogy(e14,'x-','linewidth',2,'markersize',10);
  semilogy(e15,'*-','linewidth',2,'markersize',10);
  semilogy(e19,'+-','linewidth',2,'markersize',10);
  legend('(11)','(12)','(13)','(14)','(15)','(19)')
end

