function [g,er]=avit1(a,b,verbose,maxit,nograph)
% function [g,er]=avit1(a,b,verbose,maxit,nograph)
% Computing the geometric mean g of pd matrices a,b by means of the
% Average iteration in the version given by equation (12)
% maxit is the maximum number of iterations
% verbose: if  true then the error at each step is printed at run time
% if false than no print at run time
% nograph: if true, the iterations are halted if the error is less than
% 1.e-14 or if it starts increasing, 
% if nograph is false, then all the maxit iteration are performed% In output
% g is the geometric mean 
% er is the vector with the errors per step
% 
epsi = 1.e-14;
a0 = a; b0 = b; er = 0;
normA = norm(a,inf ); normB = norm(b,inf ); 
nrm = sqrt(normA*normB);
errold = inf;
for it=1:maxit
    b1 = (a0+b0)/2;
    a1 = a0*(b1\b0);
    errA = norm(a1-a0,inf); errB = norm(b1-b0,inf);
    a0 = a1; b0 = b1;
    err = max(errA,errB);
    er(it) = err/nrm;
    if verbose
        fprintf('step=%d, errA=%e, errB=%e\n',it,errA,errB);
    end    
    if (err<epsi*nrm || err>errold&&it>10) && nograph
        g = a0;
        return
    end
    errold = err;
end
g = a0;
end
