function [g,er]=avit_3_term_scaled(a,b,verbose,maxit,nograph)
% function [g,er]=avit_3_term_scaled(a,b,verbose,maxit)
% Computing the geometric mean g of pd matrices a,b by means of the
% three-term relation according to equation (14) modified by means
% of scaling to accelerate convergence
% maxit is the maximum number of iterations
% verbose: if  true then the error at each step is printed at run time
% if false than no print at run time
% nograph: if true, the iterations are halted if the error is less than
% 1.e-14 or if it starts increasing, 
% if nograph is false, then all the maxit iteration are performed
% In output
% g is the geometric mean 
% er is the vector with the errors per step
% 
maxit = maxit-1; 
epsi = 1.e-14;
n = size(a,1);
a0 = a;
ra = chol(a);
rb = chol(b);
dra = diag(ra); drb = diag(rb);
lda = sum(log(dra));ldb = sum(log(drb));
lf = -(lda+ldb)/n;

%da=det(a);db=det(b); %f=(da*db)^(-1/(2*n));
%g0=(da/db)^(-1/(2*n))
lg0 = -(lda+ldb)/(2*n);
g0 = exp(lg0);
a1 = 0.5*(g0*a+(1/g0)*b);
%g1=(det(a1)^2/(da*db))^(-1/(2*n));
normA = norm(a,inf ); normB = norm(b,inf ); 
nrm = sqrt(normA*normB);
errold = inf;
er = zeros(maxit,1);
er(1) = norm(a1-a0,inf);
for it=1:maxit
%eia1=eig(a1)
    r = chol(a1);
    s = a0/r; s = s*s';
   % g1=((det(r))^(-2/n))/f;
    lg1 = -2*sum(log(diag(r)))/n-lf;
    g1 = exp(lg1);
%    s=(a0/a1)*a0;

    a2 = s*(-g0^2/g1)+2*(g0/g1)*a0+g1*a1;
    a2 = a2*0.5;
    %a2=0.5*(a1+2*a0-s);
    err = norm(a2-a1,inf );
    er(it+1) = err/nrm;
    a0 = a1; a1 = a2;
    g0 = g1;
    if verbose
        fprintf('step=%d, errA=%e\n',it,err/nrm);
    elseif (err<epsi*nrm || err>errold && it>10) && nograph
        g = a0;
        return
    end
    errold = err;
end
g = a0;
end
