function [g,er]=avit_sign_scaled(a,b,verbose,maxit,nograph)
% function [g,er]=avit_sign_scaled(a,b,verbose,maxit)
% Computing the geometric mean g of pd matrices a,b by means of the
% sign function iteration (15) modified by means of scaling in order to
% accelerate convergence
% maxit is the maximum number of iterations
% verbose: if  true then the error at each step is printed at run time
% if false than no print at run time
% nograph: if true, the iterations are halted if the error is less than
% 1.e-14 or if it starts increasing, 
% if nograph is false, then all the maxit iteration are performed
% In output
% g is the geometric mean 
% er is the vector with the errors per step
% 
epsi = 1.e-14;
er = 0;
n = size(a,1);
x0 = a;  y0 = inv(b);
normA = norm(a,inf ); normB = norm(b,inf ); 
nrm = sqrt(normA*normB);
errold = inf;
for it=1:maxit
    % Compute the scaling factor by avoiding overflow
      ry = chol(y0);
      rx = chol(x0);
      gx = 2*sum(log(diag(rx)));
      gy = 2*sum(log(diag(ry)));
      gk = 1/exp((gx+gy)*(1/(2*n))); 
      x0 = gk*x0; y0 = gk*y0;
    % invert x0 and y0
      rxi = rx\eye(n);
      ryi = ry\eye(n);
    % scaling matrices
      xi=rxi*rxi'; yi=ryi*ryi';
      xi = xi*(1/gk); yi = yi*(1/gk);
      % matrix sign iteration
    x1 = 0.5*(x0+yi);
    y1 = 0.5*(y0+xi);
    errA = norm(x1-x0,inf ); errB = norm(y1-y0,inf );
    x0 = x1; y0 = y1;
    er(it)=errA/nrm;
    if verbose
        fprintf('step=%d, errX=%e, errY=%e\n',it,errA/nrm,errB/nrm);
    end
    if (errA<epsi*nrm || (errA>errold && it>10)) && nograph
        g = x0;
        return
    end
    errold = errA;
end
g = x0;
end
