function [g,err]=avit_unstable(a,b,verbose,maxit)
% function [g,er]=avit_unstable(a,b,verbose,maxit)
% Computing the geometric mean g of pd matrices a,b by means of the
% unstable iteration  (13)
% maxit is the maximum number of iterations
% verbose, if  true then the error at each step is printed at run time
% and all the iteration are performed untill the error exceeds 1.e3.
% In output, the vector er of errors 
% verbose, if false than no print at run time, and the iterations are 
% halted if the error is less than 1.e-14 or if it starts increasing
% In output
% g is the geometric mean 
% er is the vector with the errors per step
epsi=1.e-14;
a0=a;a0=b;
normA=norm(a); normB=norm(b); nrm=sqrt(normA*normB);
for it=1:maxit
    s=(a/a0)*b;
    a1=0.5*(a0+s);
    errA=norm(a1-a0);
    a0=a1; 
    if verbose
        fprintf('step=%d, errA=%e\n',it,errA);
    end
    err(it)=errA;
    if errA<epsi*nrm || (errA>1.e2 && it>3)
        g=a0;
        return
    end
end
g=a0;
end
