function [A, B, stata, statb, statg]=data_set(test,ntests,n)
% This function generates nxn matrices A{i} and B{i} for i=1,...,ntests, from 
% dataset test, where test=1,2,3,4.
% On output, stata, statb, and statg are quartuples containing mean value of the 
% condition number,standard deviation, minimum and maximum value for the matrices
% a,b, and for the function G(a,b)

rng(1);
if test<1 || test>4
    disp('assign a value for test in the range [1,3]')
    return
end
for nt=1:ntests
  switch test
    case 1 % Ill conditioned random matrices
      maxit = 25;
      m = randn(n); m = m*m'; m = m/norm(m)+1.e-5*eye(n);
      m = m^2; m = (m+m')/2; a = m/norm(m);
      m = randn(n); m = m*m'; m = m/norm(m)+1.e-5*eye(n);
      m = m^2; m = (m+m')/2; b = m/norm(m);
    case 2  % Well conditioned random matrices
      maxit = 10;
      m = randn(n); m = m*m'; m = m/norm(m)+1.e-5*eye(n); m = m^(1/4);
      m = (m+m')/2; a = m/norm(m);
      m = randn(n); m = m*m'; m = m/norm(m)+1.e-5*eye(n); m = m^(1/4); 
      m = (m+m')/2; b = m/norm(m);
    case 3 % random ill conditioned but close matrices
      maxit = 25;
      m = randn(n); m = m*m'; m = m/norm(m)+1.e-5*eye(n);
      m = m*m; m=(m+m')/2; a=m/norm(m);
      m = randn(n); m = m*m'; m=(m+m')/2; m=m/norm(m); 
      b = a+m*1.e-4;b = b/norm(b);
    case 4 % Well-conditioned close matrices
      maxit = 10;
      m = randn(n); m = m*m'; m=m/norm(m)+1.e-5*eye(n); m=m^(1/4); m=(m+m')/2; a=m/norm(m);
      m = randn(n); m = m*m'; m=(m+m')/2; m=m/norm(m);b=a+m*1.e-4;b=b/norm(b);
  end
  A{nt} = a;
  B{nt} = b;
  ca(nt) = cond(a);
  cb(nt) = cond(b);
  if n<=20
    AB=[a/norm(a),b/norm(b)]; z=sqrt(b/a); 
    M1=inv(kron(eye(n),inv(z))+kron(inv(z),eye(n)));
    M2=inv(kron(eye(n),z)+kron(z,eye(n)));
    cg(nt) = norm([M1,M2])*norm(AB,'fro');
  end
end
mca=mean(ca);
stdca=std(ca);
minca=min(ca);
maxca=max(ca);

mcb=mean(cb);
stdcb=std(cb);
mincb=min(cb);
maxcb=max(cb);

if n<=20
  mcg=mean(cg);
  stdcg=std(cg);
  mincg=min(cg);
  maxcg=max(cg);
  statg=[mcg,stdcg,mincg,maxcg];
else
  statg=[];  
end  
stata=[mca,stdca,minca,maxca];
statb=[mcb,stdcb,mincb,maxcb];
end
